@@ -15,7 +15,7 @@
 // 
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 // 
 
 define( "DB_LOG_OFF", 0 );
@@ -30,8 +30,22 @@ function dbConnect()
 {
     global $dbConn;
 
+	if (strpos(ZM_DB_HOST, ':')) {
+		// Host variable may carry a port or socket.
+		list($host, $portOrSocket) = explode(':', ZM_DB_HOST, 2);
+			if (is_numeric($portOrSocket)) {
+				$socket = ':host='.$host . ';port='.$portOrSocket;
+			} else {
+				$socket = ':unix_socket='.$portOrSocket;
+			}
+	} else {
+		$socket = ':host='.ZM_DB_HOST;
+	}
+
 	try {
-		$dbConn = new PDO( ZM_DB_TYPE . ':host=' . ZM_DB_HOST . ';dbname='.ZM_DB_NAME, ZM_DB_USER, ZM_DB_PASS );
+		$dbConn = new PDO( ZM_DB_TYPE . $socket . ';dbname='.ZM_DB_NAME, ZM_DB_USER, ZM_DB_PASS );
+		$dbConn->setAttribute(PDO::ATTR_EMULATE_PREPARES, false);
+		$dbConn->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
 	} catch(PDOException $ex ) {
 		echo "Unable to connect to ZM db." . $ex->getMessage();
 		$dbConn = null;
@@ -80,7 +94,7 @@ function dbLog( $sql, $update=false )
 
 function dbError( $sql )
 {
-    Fatal( "SQL-ERR '".mysql_error()."', statement was '".$sql."'" );
+    Fatal( "SQL-ERR '".$dbConn->errorInfo()."', statement was '".$sql."'" );
 }
 
 function dbEscape( $string )
@@ -111,7 +125,7 @@ function dbQuery( $sql, $params=NULL ) {
             $result = $dbConn->query( $sql );
         }
     } catch(PDOException $e) {
-		Fatal( "SQL-ERR '".$e.getMessage()."', statement was '".$sql."'" );
+		Fatal( "SQL-ERR '".$e->getMessage()."', statement was '".$sql."'" );
     }
     return( $result );
 }
